@@ -40,6 +40,8 @@ char *        eel_gnome_make_terminal_command                         (const cha
 
 /* Open up a new terminal, optionally passing in a command to execute */
 void          eel_gnome_open_terminal                                 (const char               *command);
+void          eel_gnome_open_terminal_on_screen                       (const char               *command,
+								       GdkScreen                *screen);
 
 /* Create an icon selection dialog */
 GtkWidget *   eel_gnome_icon_selector_new                             (const char               *title,
@@ -48,18 +50,8 @@ GtkWidget *   eel_gnome_icon_selector_new                             (const cha
 								       EelIconSelectionFunction  selected,
 								       gpointer                  callback_data);
 									 
-/* Execute a command. To be used in place of the exec family commands. This function
- * protects against creating zombie processes.
- */
-void          eel_gnome_shell_execute                                 (const char               *command);
-
 char         *eel_bonobo_make_registration_id                         (const char               *iid);
 
-void          eel_bonobo_pbclient_set_value_async                     (Bonobo_PropertyBag        bag,
-								       const char               *key,
-								       CORBA_any                *value,
-								       CORBA_Environment        *opt_ev);
-
 GladeXML     *eel_glade_get_file                                      (const char               *filename,
 								       const char               *root,
 								       const char               *domain,
